@@ -9,6 +9,7 @@ def not_stdlib_filter(module, prefix=None):
     if prefix is None:
         prefix = sys.prefix
     prefix = os.path.join(os.path.realpath(prefix), '')
+
     rp = os.path.realpath(module.filename)
     if rp.startswith(prefix):
         rest = rp[len(prefix):]
@@ -18,6 +19,23 @@ def not_stdlib_filter(module, prefix=None):
             return True
         else:
             return False
+
+    if os.path.exists(os.path.join(prefix, ".Python")):
+       # Virtualenv
+       fn = os.path.join(prefix, "lib", "python%d.%d"%(sys.version_info[:2]), "orig-prefix.txt")
+       if os.path.exists(fn):
+           with open(fn, 'rU') as fp:
+               prefix = fp.read().strip()
+           
+           if rp.startswith(prefix):
+               rest = rp[len(prefix):]
+               if '/site-python/' in rest:
+                   return True
+               elif '/site-packages/' in rest:
+                   return True
+               else:
+                   return False
+
     return True
 
 def not_system_filter(module):
