@@ -4,10 +4,11 @@ from . import pydoc
 from . import docutils
 from . import pyopengl
 from . import sip
-from . import email
 from . import numpy
 from . import scipy
 from . import matplotlib
+from . import pyenchant
+from . import lxml
 
 from . import virtualenv
 from . import pyside
