@@ -29,6 +29,7 @@ import os
 import signal
 import py2app
 import hashlib
+from distutils.sysconfig import get_config_var
 
 DIR_NAME=os.path.dirname(os.path.abspath(__file__))
 
@@ -134,7 +135,7 @@ class TestBasicApp (unittest.TestCase):
 
     #
     # End of setup code
-    # 
+    #
 
     def test_basic_start(self):
         p = self.start_app()
@@ -186,11 +187,11 @@ class TestBasicApp (unittest.TestCase):
             ln = p.stdout.readline()
             self.assertEqual(ln.strip(), b"xdrlib")
 
-        if sys.prefix.startswith('/System'):
+        if sys.prefix.startswith('/System') or '--alias' in self.py2app_args:
             # py2app is included as part of the system install
             p.stdin.write('import_module("py2app")\n'.encode('latin1'))
             p.stdin.flush()
-            ln = p.stdout.readline().decode('utf-8')
+            ln = p.stdout.readline()
             self.assertEqual(ln.strip(), b"py2app")
 
 
@@ -219,12 +220,43 @@ class TestBasicApp (unittest.TestCase):
             p.stdout.close()
         self.assertChecksumsSame()
 
+
+    def test_framework_versions(self):
+        fwk = get_config_var('PYTHONFRAMEWORK')
+        path = os.path.join(
+                self.app_dir,
+            'dist/BasicApp.app/Contents/Frameworks/%s.framework'%(fwk,))
+        if not os.path.exists(path):
+            return
+
+        names = set(os.listdir(os.path.join(path, 'Versions')))
+        ver_str = '%d.%d' % sys.version_info[:2]
+        self.assertEqual(names, { 'Current', ver_str })
+        self.assertEqual(os.readlink(os.path.join(path, 'Versions', 'Current')), ver_str)
+
+        self.assertEqual(os.readlink(os.path.join(path, fwk)), os.path.join('Versions', 'Current', fwk))
+        self.assertEqual(os.readlink(os.path.join(path, 'Resources')), os.path.join('Versions', 'Current', 'Resources'))
+
 class TestBasicAliasApp (TestBasicApp):
     py2app_args = [ '--alias', ]
 
 class TestBasicSemiStandaloneApp (TestBasicApp):
     py2app_args = [ '--semi-standalone', ]
 
+class TestBasicAppScriptName (unittest.TestCase):
+    app_dir = os.path.join(DIR_NAME, 'basic_app2')
+    def test_email_not_included(self):
+        path = os.path.join(
+                self.app_dir, 'dist/BasicApp.app/Contents/Resources/lib/python%d.%d' % sys.version_info[:2])
+        if os.path.exists(os.path.join(path, 'email')):
+            self.fail("'email' package copied into a semi-standalone build")
+
+class TestBasicAliasAppScriptName (TestBasicAppScriptName):
+    py2app_args = [ '--alias', ]
+
+class TestBasicSemiStandaloneAppScriptName (TestBasicAppScriptName):
+    py2app_args = [ '--semi-standalone', ]
+
 class TestBasicAppWindowsLineEnd (TestBasicApp):
     app_dir = os.path.join(DIR_NAME, 'basic_app_winle')
 
@@ -345,4 +377,3 @@ class TestOptimized2 (TestBasicApp):
 
 if __name__ == "__main__":
     unittest.main()
-
